aboutsummaryrefslogtreecommitdiffstats
path: root/embed/ephy-embed-utils.c
diff options
context:
space:
mode:
authorXan Lopez <xan@gnome.org>2009-06-05 21:32:55 +0800
committerXan Lopez <xan@gnome.org>2009-06-05 22:54:08 +0800
commit8f3aa835aa3fb12e8f9805c3ecb454027398102c (patch)
tree94223e73426ef759ad4176c33ef3a659895eb0ac /embed/ephy-embed-utils.c
parent1d49b43e4da3c5153a444596b24340d40ad98d31 (diff)
downloadgsoc2013-epiphany-8f3aa835aa3fb12e8f9805c3ecb454027398102c.tar
gsoc2013-epiphany-8f3aa835aa3fb12e8f9805c3ecb454027398102c.tar.gz
gsoc2013-epiphany-8f3aa835aa3fb12e8f9805c3ecb454027398102c.tar.bz2
gsoc2013-epiphany-8f3aa835aa3fb12e8f9805c3ecb454027398102c.tar.lz
gsoc2013-epiphany-8f3aa835aa3fb12e8f9805c3ecb454027398102c.tar.xz
gsoc2013-epiphany-8f3aa835aa3fb12e8f9805c3ecb454027398102c.tar.zst
gsoc2013-epiphany-8f3aa835aa3fb12e8f9805c3ecb454027398102c.zip
Move all methods, signals and properties from EphyEmbed and EphyBaseEmbed to EphyWebView.
Those two embed classes are pretty much dummy leftovers, so it should be easier to remove them now.
Diffstat (limited to 'embed/ephy-embed-utils.c')
-rw-r--r--embed/ephy-embed-utils.c16
1 files changed, 8 insertions, 8 deletions
diff --git a/embed/ephy-embed-utils.c b/embed/ephy-embed-utils.c
index e00e23528..672c46bc3 100644
--- a/embed/ephy-embed-utils.c
+++ b/embed/ephy-embed-utils.c
@@ -80,28 +80,28 @@ ephy_embed_utils_link_message_parse (char *message)
/**
* ephy_embed_utils_get_title_composite:
- * @embed: an #EphyEmbed
+ * @view: an #EphyView
*
* Returns the title of the web page loaded in @embed.
*
* This differs from #ephy_embed_utils_get_title in that this function
* will return a special title while the page is still loading.
*
* Return value: @embed's web page's title. Will never be %NULL.
**/
const char *
-ephy_embed_utils_get_title_composite (EphyEmbed *embed)
+ephy_embed_utils_get_title_composite (EphyWebView *view)
{
const char *title = "";
const char *loading_title;
gboolean is_loading, is_blank;
- g_return_val_if_fail (EPHY_IS_EMBED (embed), NULL);
+ g_return_val_if_fail (EPHY_IS_WEB_VIEW (view), NULL);
- is_loading = ephy_embed_get_load_status (embed);
- is_blank = ephy_embed_get_is_blank (embed);
- loading_title = ephy_embed_get_loading_title (embed);
- title = ephy_embed_get_title (embed);
+ is_loading = ephy_web_view_get_load_status (view);
+ is_blank = ephy_web_view_get_is_blank (view);
+ loading_title = ephy_web_view_get_loading_title (view);
+ title = ephy_web_view_get_title (view);
if (is_blank)
{
@@ -80,28 +80,28 @@ ephy_embed_utils_link_message_parse (char *message)
* will return a special title while the page is still loading.
*
- * Return value: @embed's web page's title. Will never be %NULL.
+ * Return value: @view's web page's title. Will never be %NULL.
**/
const char *